####################
 Naming conventions
####################

This is the current naming conventions for datasets :

`Anemoi Naming Conventions
<https://anemoi-registry.readthedocs.io/en/latest/naming-conventions.html>`_
